"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generatePattern = void 0;
const paths_enum_1 = require("../enums/paths.enum");
const fileFinder_1 = require("../fileFinder/fileFinder");
const writeFile_1 = require("./writeFile");
/** Searches for files that fit the pattern, and returns a code string based on the given code patter.
 * @param filePath The path and name of the generated file to be made, like 'src/Example/test.ts'.
 * @param fileNamePattern The pattern to search files for. Best if used as an extension, like '.screen.ts'.
 * @param codePatterns An array of string patterns to apply to found files:
 * Example pattern: "import { $name } from '$importPath';"
 * ```
 * - '$name' gets the first section of the file name: "MyScreen"
 * - '$fileName' gets the entire file name: "MyScreen.screen.ts"
 * - '$importPath' gets the file path without the last extension: "src/screens/MyScreen.screen"
 * - '$path' gets the full path: "src/screens/MyScreen.screen.ts"
 * ```
 * @param options Options for the search
 * ```
 * - folder: The folder to search in. Defaults to './'
 * ```
 */
const generatePattern = ({ filePath, fileNamePattern, codePatterns, options, }) => {
    const { folder = paths_enum_1.paths.root } = options || {};
    const files = (0, fileFinder_1.findFiles)(folder || paths_enum_1.paths.root, fileNamePattern);
    let code = ``;
    codePatterns.forEach(codePattern => {
        codePattern.forEach(codeLine => {
            if (codeLine.static) {
                code += `${codeLine.pattern}\n`;
            }
            else {
                files.forEach(file => {
                    code += `${replacePatternIdentifiers(codeLine.pattern, file)}\n`;
                });
            }
        });
        code += `${"//@SPACE" /* Tokens.Space */}\n`;
    });
    (0, writeFile_1.writeFile)(filePath, code);
    console.log(`Successfully generated from markdown ${filePath}`);
};
exports.generatePattern = generatePattern;
const replacePatternIdentifiers = (pattern, file) => {
    return pattern
        .replaceAll('$name', file.name)
        .replaceAll('$importName', file.importName)
        .replaceAll('$path', file.path)
        .replaceAll('$fileName', file.fileName)
        .replaceAll("// pattern" /* Tokens.Pattern */, '');
};
