"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.recursiveFileSearch = exports.findFiles = void 0;
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
const findFiles = (startPath, filter) => {
    const result = [];
    const callback = (file) => {
        result.push(file);
    };
    (0, exports.recursiveFileSearch)(startPath, filter, callback);
    return result;
};
exports.findFiles = findFiles;
const recursiveFileSearch = (startPath, filter, callback) => {
    if (!fs_1.default.existsSync(startPath)) {
        console.log('Directory does not exist', startPath);
        return;
    }
    const files = fs_1.default.readdirSync(startPath);
    for (let i = 0; i < files.length; i++) {
        const filename = path_1.default.join(startPath, files[i]);
        if (filename.indexOf('node_modules') > -1)
            continue;
        const stat = fs_1.default.lstatSync(filename);
        if (stat.isDirectory()) {
            (0, exports.recursiveFileSearch)(filename, filter, callback);
        }
        else if (`.${filename.split('.').slice(1).join('.')}` === filter) {
            const parsedFileName = filename.split('/').pop();
            const parsedName = parsedFileName?.split('.')[0];
            const parsedImportName = parsedFileName
                ?.substring(0, parsedFileName.lastIndexOf('.'))
                .split('/')
                .pop();
            callback({
                path: filename,
                fileName: parsedFileName || '',
                importName: parsedImportName || '',
                name: parsedName || '',
            });
        }
    }
};
exports.recursiveFileSearch = recursiveFileSearch;
